@@ -25,7 +25,10 @@
 #include <glib/gi18n-lib.h>
 #include <stdio.h>
 #include <string.h>
-#include <id3.h>
+#include <stdlib.h> // for 'system'
+#ifdef ENABLE_MP3
+#   include <id3.h>
+#endif
 #include <errno.h>
 
 #include "about.h"
@@ -259,10 +262,17 @@ void Show_About_Window (void)
     Label = gtk_label_new(temp);
     gtk_box_pack_start(GTK_BOX(VBox),Label,FALSE,TRUE,0);
 
+#ifdef ENABLE_MP3 // FIX ME : should separate gtk and id3lib
     sprintf(temp,_("(using: GTK+ %d.%d.%d and id3lib %d.%d.%d)"),GTK_MAJOR_VERSION,GTK_MINOR_VERSION,
         GTK_MICRO_VERSION,ID3LIB_MAJOR_VERSION,ID3LIB_MINOR_VERSION,ID3LIB_PATCH_VERSION);
     Label = gtk_label_new(temp);
     gtk_box_pack_start(GTK_BOX(VBox),Label,FALSE,TRUE,0);
+#endif
+
+#ifndef ENABLE_MP3
+    Label = gtk_label_new(_("(MP3 file support disabled)"));
+    gtk_box_pack_start(GTK_BOX(VBox),Label,FALSE,TRUE,0);
+#endif
 
 #ifndef ENABLE_OGG
     Label = gtk_label_new(_("(Ogg Vorbis file support disabled)"));
@@ -483,7 +493,7 @@ void Show_About_Window (void)
 void About_Window_Go_To_Home_Page (void)
 {
 #ifdef WIN32
-    ET_win32_notify_uri(WEBPAGE);
+    ET_Win32_Notify_Uri(WEBPAGE);
 #else
     system("gnome-moz-remote "WEBPAGE);
 #endif
