@@ -34,6 +34,9 @@
 #include "charset.h"
 #include "setting.h"
 
+#ifdef WIN32
+    #include "win32dep.h"
+#endif
 
 
 /****************
@@ -256,18 +259,85 @@ get_encoding_from_locale (const char *locale)
  * Return the locale from LANG if exists, else from LC_ALL
  *
  * http://www.opengroup.org/onlinepubs/009695399/basedefs/xbd_chap08.html#tag_08_02
+ * 
+ * LANG
+ *     This variable shall determine the locale category for native language,
+ *     local customs, and coded character set in the absence of the LC_ALL and
+ *     other LC_* ( LC_COLLATE , LC_CTYPE , LC_MESSAGES , LC_MONETARY , LC_NUMERIC ,
+ *     LC_TIME ) environment variables. This can be used by applications to 
+ *     determine the language to use for error messages and instructions, collating
+ *     sequences, date formats, and so on.
+ * LC_ALL
+ *     This variable shall determine the values for all locale categories. The
+ *     value of the LC_ALL environment variable has precedence over any of the
+ *     other environment variables starting with LC_ ( LC_COLLATE , LC_CTYPE ,
+ *     LC_MESSAGES , LC_MONETARY , LC_NUMERIC , LC_TIME ) and the LANG environment
+ *     variable.
+ * LC_COLLATE
+ *     This variable shall determine the locale category for character collation.
+ *     It determines collation information for regular expressions and sorting,
+ *     including equivalence classes and multi-character collating elements, in
+ *     various utilities and the strcoll() and strxfrm() functions. Additional
+ *     semantics of this variable, if any, are implementation-defined.
+ * LC_CTYPE
+ *     This variable shall determine the locale category for character handling
+ *     functions, such as tolower(), toupper(), and isalpha(). This environment
+ *     variable determines the interpretation of sequences of bytes of text data
+ *     as characters (for example, single as opposed to multi-byte characters),
+ *     the classification of characters (for example, alpha, digit, graph), and
+ *     the behavior of character classes. Additional semantics of this variable,
+ *    if any, are implementation-defined.
+ * LC_MESSAGES
+ *     This variable shall determine the locale category for processing affirmative
+ *     and negative responses and the language and cultural conventions in which
+ *     messages should be written. [XSI] [Option Start]  It also affects the behavior
+ *     of the catopen() function in determining the message catalog. [Option End]
+ *     Additional semantics of this variable, if any, are implementation-defined.
+ *     The language and cultural conventions of diagnostic and informative messages
+ *     whose format is unspecified by IEEE Std 1003.1-2001 should be affected by
+ *     the setting of LC_MESSAGES .
+ * LC_MONETARY
+ *     This variable shall determine the locale category for monetary-related
+ *     numeric formatting information. Additional semantics of this variable, if
+ *     any, are implementation-defined.
+ * LC_NUMERIC
+ *     This variable shall determine the locale category for numeric formatting
+ *     (for example, thousands separator and radix character) information in
+ *     various utilities as well as the formatted I/O operations in printf() and
+ *     scanf() and the string conversion functions in strtod(). Additional semantics
+ *     of this variable, if any, are implementation-defined.
+ * LC_TIME
+ *     This variable shall determine the locale category for date and time formatting
+ *     information. It affects the behavior of the time functions in strftime().
+ *     Additional semantics of this variable, if any, are implementation-defined.
+ * 
+ * 
+ * The values of locale categories shall be determined by a precedence order; the
+ * first condition met below determines the value:
+ * 
+ *    1. If the LC_ALL environment variable is defined and is not null, the value
+ *       of LC_ALL shall be used.
+ *    2. If the LC_* environment variable ( LC_COLLATE , LC_CTYPE , LC_MESSAGES ,
+ *       LC_MONETARY , LC_NUMERIC , LC_TIME ) is defined and is not null, the value
+ *       of the environment variable shall be used to initialize the category that
+ *       corresponds to the environment variable.
+ *    3. If the LANG environment variable is defined and is not null, the value of
+ *       the LANG environment variable shall be used.
+ *    4. If the LANG environment variable is not set or is set to the empty string,
+ *       the implementation-defined default locale shall be used.
+ * 
  */
 const gchar *get_locale (void)
 {
-    if (g_getenv("LANG"))
-        return g_getenv("LANG");
-    
-    else if (g_getenv("LC_ALL"))
+    if (g_getenv("LC_ALL"))
         return g_getenv("LC_ALL");
     
     else if (g_getenv("LC_CTYPE"))
         return g_getenv("LC_CTYPE");
     
+    else if (g_getenv("LANG"))
+        return g_getenv("LANG");
+    
     else
         return NULL;
 }
@@ -409,19 +479,19 @@ gchar *convert_from_utf8 (const char *string)
  */
 gchar *filename_to_display (const gchar *string)
 {
+    gchar *ret = NULL;
     GError *error = NULL;
-    
+
     if (!string)
         return NULL;
 
     if (g_utf8_validate(string, -1, NULL))
     {
         // String already in UTF-8
-        return g_strdup(string);
+        ret = g_strdup(string);
     }else
     {
         const gchar *char_encoding;
-        gchar *ret = NULL;
 
         // Get encoding associated to the locale without using UTF-8 (ex , if LANG=fr_FR.UTF-8 it will return ISO-8859-1)
         char_encoding = get_encoding_from_locale(get_locale());
@@ -446,11 +516,16 @@ gchar *filename_to_display (const gchar *string)
                         escaped_str, error && error->message ? error->message : _("Invalid UTF-8"));
             g_clear_error(&error);
 
-            return escaped_str;
+            ret = escaped_str;
         }
-
-        return ret;
     }
+
+#ifdef WIN32
+    ET_Win32_Path_Remove_Trailing_Slash(ret);
+    ET_Win32_Path_Replace_Slashes(ret);
+#endif
+
+    return ret;
 }
 
 /*
@@ -540,9 +615,13 @@ gchar *filename_from_display (const gchar *string)
                     escaped_str, error && error->message ? error->message : _("Invalid UTF-8"));
         g_clear_error(&error);
 
-        return escaped_str;
+        ret = escaped_str;
     }
 
+#ifdef WIN32
+    ET_Win32_Path_Replace_Backslashes(ret);
+#endif
+
     return ret; // We need to catch errors (e.g. temp=NULL) in the real code
 }
 
