@@ -25,7 +25,7 @@
 
 #include <glib.h>
 #include <gdk/gdktypes.h>
-#include <config.h> // For definition of ENABLE_OGG
+#include <config.h> // For definition of ENABLE_OGG, ...
 
 
 /***************
@@ -232,7 +232,10 @@ struct _ET_File_Description
  */
 static const ET_File_Description ETFileDescription[] = 
 {
+#ifdef ENABLE_MP3
     {MP3_FILE,     ".mp3",  ID3_TAG},
+    {MP2_FILE,     ".mp2",  ID3_TAG},
+#endif
 #ifdef ENABLE_OGG
     {OGG_FILE,     ".ogg",  OGG_TAG},
 #endif
@@ -240,7 +243,6 @@ static const ET_File_Description ETFileDescription[] =
     {FLAC_FILE,    ".flac", FLAC_TAG},
     {FLAC_FILE,    ".fla",  FLAC_TAG},
 #endif
-    {MP2_FILE,     ".mp2",  ID3_TAG},
     {MPC_FILE,     ".mpc",  APE_TAG},  // Implemented by Artur Polaczynski
     {MPC_FILE,     ".mp+",  APE_TAG},  // Implemented by Artur Polaczynski
     {MPC_FILE,     ".mpp",  APE_TAG},  // Implemented by Artur Polaczynski
@@ -358,6 +360,7 @@ gboolean ET_Free_Displayed_File_List     (void);
 ET_File   *ET_File_Item_New       (void);
 File_Name *ET_File_Name_Item_New  (void);
 File_Tag  *ET_File_Tag_Item_New   (void);
+gboolean   ET_Free_File_Tag_Item  (File_Tag *FileTag);
 gboolean   ET_Free_File_List_Item (ET_File *ETFile);
 
 gboolean ET_Copy_File_Tag_Item         (ET_File *ETFile, File_Tag *FileTag);
@@ -447,6 +450,7 @@ gint ET_Comp_Func_Sort_File_By_Descending_File_Samplerate (ET_File *ETFile1, ET_
 void ET_Debug_Print_File      (ET_File *ETFile,   gchar *file, gint line, gchar *function);
 void ET_Debug_Print_File_List (GList *ETFileList, gchar *file, gint line, gchar *function);
 void ET_Debug_Print_Artist_Album_List (gchar *file, gint line, gchar *function);
+void ET_Debug_Print_Time (gchar *msg);
 
 
 #endif /* __ET_CORE_H__ */
