@@ -39,6 +39,7 @@
 #include "id3_tag.h"
 #include "misc.h"
 #include "setting.h"
+#include "picture.h"
 #include "charset.h"
 
 
@@ -582,6 +583,7 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
     FLAC__metadata_object_delete(vc_block);
     FLAC__metadata_simple_iterator_delete(iter);
 
+#ifdef ENABLE_MP3
     /* If no FLAC vorbis tag found : we try to get the ID3 tag if it exists
      * (will be deleted when writing the tag */
     if ( FileTag->title       == NULL
@@ -643,6 +645,7 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
 
         return rc;
     }
+#endif
 
     return TRUE;
 }
@@ -947,6 +950,7 @@ gboolean Flac_Tag_Write_File_Tag (ET_File *ETFile)
     if (vc_found_svg)
         FLAC__metadata_object_delete(vc_block_svg);
 
+#ifdef ENABLE_MP3
     /*
      * Write also the ID3 tags (ID3v1 and/or ID3v2) if wanted (as needed by some players)
      */
@@ -969,6 +973,7 @@ gboolean Flac_Tag_Write_File_Tag (ET_File *ETFile)
         Id3tag_Write_File_Tag(ETFile_tmp);
         ET_Free_File_List_Item(ETFile_tmp);
     }
+#endif
 
     g_free(filename_utf8);
     return TRUE;
