@@ -20,7 +20,6 @@
 
 #include <config.h>
 
-#include <id3.h>
 #include <gtk/gtk.h>
 #include <glib/gi18n-lib.h>
 #include <stdio.h>
@@ -32,15 +31,19 @@
 #include "id3_tag.h"
 #include "id3lib/id3_bugfix.h"
 #include "picture.h"
-#include "genres.h"
 #include "easytag.h"
 #include "browser.h"
+#include "genres.h"
 #include "setting.h"
 #include "misc.h"
 #include "et_core.h"
 #include "msgbox.h"
 #include "charset.h"
 
+#ifdef ENABLE_MP3
+
+#include <id3.h>
+
 
 /****************
  * Declarations *
@@ -1005,43 +1008,6 @@ gchar *Id3tag_Get_Error_Message(ID3_Err error)
 
 
 
-/*
- * Returns the corresponding genre value of the input string (for ID3v1.x),
- * else returns 0xFF (unknown genre, but not invalid).
- */
-guchar Id3tag_String_To_Genre (gchar *genre)
-{
-    guint i;
-
-    if (genre != NULL)
-    {
-        for (i=0; i<=GENRE_MAX; i++)
-            if (strcasecmp(genre,id3_genres[i])==0)
-                return (guchar)i;
-    }
-    return (guchar)0xFF;
-}
-
-
-/*
- * Returns the name of a genre code if found
- * Three states for genre code :
- *    - defined (0 to GENRE_MAX)
- *    - undefined/unknown (GENRE_MAX+1 to ID3_INVALID_GENRE-1)
- *    - invalid (>ID3_INVALID_GENRE)
- */
-gchar *Id3tag_Genre_To_String (unsigned char genre_code)
-{
-    if (genre_code>=ID3_INVALID_GENRE)    /* empty */
-        return "";
-    else if (genre_code>GENRE_MAX)        /* unknown tag */
-        return "Unknown";
-    else                                  /* known tag */
-        return id3_genres[genre_code];
-}
-
-
-
 /*
  * As the ID3Tag_Link function of id3lib-3.8.0pre2 returns the ID3v1 tags
  * when a file has both ID3v1 and ID3v2 tags, we first try to explicitely
@@ -1733,3 +1699,43 @@ gboolean Id3tag_Check_If_File_Is_Corrupted (gchar *filename)
     
     return result;
 }
+
+#endif /* ENABLE_MP3 */
+
+
+
+// Placed out #ifdef ENABLE_MP3 as not dependant of id3lib, and used in CDDB
+/*
+ * Returns the corresponding genre value of the input string (for ID3v1.x),
+ * else returns 0xFF (unknown genre, but not invalid).
+ */
+guchar Id3tag_String_To_Genre (gchar *genre)
+{
+    guint i;
+
+    if (genre != NULL)
+    {
+        for (i=0; i<=GENRE_MAX; i++)
+            if (strcasecmp(genre,id3_genres[i])==0)
+                return (guchar)i;
+    }
+    return (guchar)0xFF;
+}
+
+
+/*
+ * Returns the name of a genre code if found
+ * Three states for genre code :
+ *    - defined (0 to GENRE_MAX)
+ *    - undefined/unknown (GENRE_MAX+1 to ID3_INVALID_GENRE-1)
+ *    - invalid (>ID3_INVALID_GENRE)
+ */
+gchar *Id3tag_Genre_To_String (unsigned char genre_code)
+{
+    if (genre_code>=ID3_INVALID_GENRE)    /* empty */
+        return "";
+    else if (genre_code>GENRE_MAX)        /* unknown tag */
+        return "Unknown";
+    else                                  /* known tag */
+        return id3_genres[genre_code];
+}
