@@ -95,8 +95,8 @@ void Set_Tips_Color (GtkTooltips *tips);
 void Run_Audio_Player_Using_File_List (GList *etfilelist);
 void Run_Audio_Player_Using_Directory (void);
 void Run_Audio_Player_Using_Selection (void);
-void Run_Audio_Player_Using_Browser_Artist_List (GtkMenuItem *menuitem, gpointer data);
-void Run_Audio_Player_Using_Browser_Album_List  (GtkMenuItem *menuitem, gpointer data);
+void Run_Audio_Player_Using_Browser_Artist_List (void);
+void Run_Audio_Player_Using_Browser_Album_List  (void);
 
 gchar *Convert_Size     (gfloat size);
 gchar *Convert_Size_1   (gfloat size);
