@@ -25,6 +25,7 @@
 #include <gdk/gdk.h>
 #include <glib/gi18n-lib.h>
 #include <sys/types.h>
+#include <sys/stat.h>
 #include <fcntl.h>
 #include <string.h>
 #include <stdio.h>
@@ -36,8 +37,13 @@
 #include "misc.h"
 #include "setting.h"
 #include "msgbox.h"
+#include "bar.h"
 #include "charset.h"
 
+#ifdef WIN32
+#   include "win32dep.h"
+#endif
+
 
 /****************
  * Declarations *
@@ -68,8 +74,8 @@ void PictureEntry_Update (Picture *pic, gint select);
 
 Picture *Picture_Allocate (void);
 Picture *Picture_Copy_One (const Picture *pic);
-Picture *Picture_Copy (const Picture *pic);
-void     Picture_Free (Picture *pic);
+Picture *Picture_Copy     (const Picture *pic);
+void     Picture_Free     (Picture *pic);
 Picture *Picture_Load_File_Data (const gchar *filename);
 gboolean Picture_Save_File_Data (const Picture *pic, const gchar *filename);
 
@@ -77,6 +83,14 @@ gboolean Picture_Entry_View_Button_Pressed (GtkTreeView *treeview, GdkEventButto
 gboolean Picture_Entry_View_Key_Pressed    (GtkTreeView *treeview, GdkEvent *event, gpointer data);
 
 
+/*
+ * Note :
+ * -> MP4_TAG :
+ *      Just has one picture (PICTURE_TYPE_FRONT_COVER).
+ *      The format's don't matter to the MP4 side.
+ *
+ */
+
 /*************
  * Functions *
  *************/
@@ -90,15 +104,15 @@ void Tag_Area_Picture_Drag_Data (GtkWidget *widget, GdkDragContext *dc,
 
     gtk_drag_finish(dc, TRUE, FALSE, t);
 
-    if (info != TARGET_URI_LIST)
-        return;
-    if (!selection_data)
+    if (info != TARGET_URI_LIST
+    ||  !selection_data
+    ||  !PictureEntryView)
         return;
 
     selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(PictureEntryView));
     gtk_tree_selection_unselect_all(selection);
     
-    uri = uri_list = g_strsplit(selection_data->data, "\r\n", 0);
+    uri = uri_list = g_strsplit((const gchar *)selection_data->data, "\r\n", 0);
     while (*uri && strlen(*uri))
     {
         //Picture *pic;
@@ -140,6 +154,8 @@ void Picture_Clear_Button_Clicked (GObject *object)
     gpointer proxy;
     gint n = 0;
     
+    if (!PictureEntryView) return;
+
     model = gtk_tree_view_get_model(GTK_TREE_VIEW(PictureEntryView));
     selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(PictureEntryView));
     paths = gtk_tree_selection_get_selected_rows(selection, 0);
@@ -176,6 +192,9 @@ void Picture_Clear_Button_Clicked (GObject *object)
         PictureEntry_Clear();
 }
 
+/*
+ * - 'filename' : path + filename of picture file
+ */
 void Picture_Load_Filename (gchar *filename, gpointer user_data)
 {
     Picture *pic;
@@ -191,29 +210,45 @@ void Picture_Load_Filename (gchar *filename, gpointer user_data)
     pic = Picture_Load_File_Data(filename);
 
     filename_utf8 = filename_to_display(filename);
-    
+
     if (pic && filename_utf8)
     {
-        // By default, set the filename in the description
-        pic->description = g_path_get_basename(filename_utf8);
-        
-        // Try to identify the type of the picture from the file name
-        filename_utf8_folded = g_utf8_casefold(pic->description, -1);
-        front_folded         = g_utf8_casefold("Front", -1);
-        back_folded          = g_utf8_casefold("Back", -1);
-        cd_folded            = g_utf8_casefold("CD", -1);
-        inside_folded        = g_utf8_casefold("inside", -1);
-        //inlay_folded         = g_utf8_casefold("inlay", -1);
-        if ( strstr(filename_utf8_folded, front_folded) != NULL )
-            pic->type = PICTURE_TYPE_FRONT_COVER;
-        else if ( strstr(filename_utf8_folded, back_folded) != NULL )
-            pic->type = PICTURE_TYPE_BACK_COVER;
-        else if ( strstr(filename_utf8_folded, cd_folded) != NULL )
-            pic->type = PICTURE_TYPE_MEDIA;
-        else if ( strstr(filename_utf8_folded, inside_folded) != NULL )
-            pic->type = PICTURE_TYPE_LEAFLET_PAGE;
-        //else if ( strstr(filename_utf8_folded, inlay_folded) != NULL )
-        //    pic->type = PICTURE_TYPE_LEAFLET_PAGE;
+        // Behaviour following the tag type...
+        switch (ETCore->ETFileDisplayed->ETFileDescription->TagType)
+        {
+            case MP4_TAG:
+            {
+                pic->type = PICTURE_TYPE_FRONT_COVER;
+                break;
+            }
+            
+            // Other tag types
+            default:
+            {
+                // By default, set the filename in the description
+                pic->description = g_path_get_basename(filename_utf8);
+                
+                // Try to identify the type of the picture from the file name
+                filename_utf8_folded = g_utf8_casefold(pic->description, -1);
+                front_folded         = g_utf8_casefold("Front", -1);
+                back_folded          = g_utf8_casefold("Back", -1);
+                cd_folded            = g_utf8_casefold("CD", -1);
+                inside_folded        = g_utf8_casefold("inside", -1);
+                //inlay_folded         = g_utf8_casefold("inlay", -1);
+                if ( strstr(filename_utf8_folded, front_folded) != NULL )
+                    pic->type = PICTURE_TYPE_FRONT_COVER;
+                else if ( strstr(filename_utf8_folded, back_folded) != NULL )
+                    pic->type = PICTURE_TYPE_BACK_COVER;
+                else if ( strstr(filename_utf8_folded, cd_folded) != NULL )
+                    pic->type = PICTURE_TYPE_MEDIA;
+                else if ( strstr(filename_utf8_folded, inside_folded) != NULL )
+                    pic->type = PICTURE_TYPE_LEAFLET_PAGE;
+                //else if ( strstr(filename_utf8_folded, inlay_folded) != NULL )
+                //    pic->type = PICTURE_TYPE_LEAFLET_PAGE;
+
+                break;
+            }
+        }
 
         PictureEntry_Update(pic, 1);
 
@@ -240,6 +275,8 @@ void Picture_Add_Button_Clicked (GObject *object)
     GtkWindow *parent_window = NULL;
     static gchar *init_dir = NULL;
 
+    if (!PictureEntryView) return;
+
     parent_window = (GtkWindow *) gtk_widget_get_toplevel(GTK_WIDGET(object));
     if (!GTK_WIDGET_TOPLEVEL(parent_window))
     {
@@ -279,7 +316,23 @@ void Picture_Add_Button_Clicked (GObject *object)
     else if (MESSAGE_BOX_POSITION_MOUSE)
         gtk_window_set_position(GTK_WINDOW(FileSelectionWindow),GTK_WIN_POS_MOUSE);
     
-    gtk_file_chooser_set_select_multiple(GTK_FILE_CHOOSER(FileSelectionWindow), TRUE);
+    // Behaviour following the tag type...
+    switch (ETCore->ETFileDisplayed->ETFileDescription->TagType)
+    {
+        case MP4_TAG:
+        {
+            gtk_file_chooser_set_select_multiple(GTK_FILE_CHOOSER(FileSelectionWindow), FALSE);
+            break;
+        }
+        
+        // Other tag types
+        default:
+        {
+            gtk_file_chooser_set_select_multiple(GTK_FILE_CHOOSER(FileSelectionWindow), TRUE);
+            break;
+        }
+    }
+
     gtk_dialog_set_default_response(GTK_DIALOG(FileSelectionWindow), GTK_RESPONSE_OK);
     if (init_dir)
         gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(FileSelectionWindow),init_dir);
@@ -344,6 +397,8 @@ void Picture_Properties_Button_Clicked (GObject *object)
         };
 
 
+    if (!PictureEntryView) return;
+
     parent_window = (GtkWindow *) gtk_widget_get_toplevel(GTK_WIDGET(object));
     if (!GTK_WIDGET_TOPLEVEL(parent_window))
     {
@@ -361,8 +416,8 @@ void Picture_Properties_Button_Clicked (GObject *object)
         Picture *pic;
         GtkTreeSelection *selectiontype;
         gchar *title;
-        
-        
+        GtkTreePath *rowPath;
+
         // Get corresponding picture
         gtk_tree_model_get_iter(GTK_TREE_MODEL(model), &iter, path);
         gtk_tree_model_get(GTK_TREE_MODEL(model), &iter, PICTURE_COLUMN_DATA, &pic, -1);
@@ -405,24 +460,54 @@ void Picture_Properties_Button_Clicked (GObject *object)
         gtk_widget_set_size_request(type, 256, 256);
         gtk_box_pack_start(GTK_BOX(GTK_DIALOG(PictureTypesWindow)->vbox),ScrollWindowPictureTypes,TRUE,TRUE,0);
     
-        // Load pictures types
-        for (i = 0; i < sizeof(picture_types)/sizeof(picture_types[0]); i++)
+        // Behaviour following the tag type...
+        switch (ETCore->ETFileDisplayed->ETFileDescription->TagType)
         {
-            GtkTreeIter itertype;
-            
-            gtk_list_store_append(store, &itertype);
-            gtk_list_store_set(store, &itertype,
-                               PICTURE_TYPE_COLUMN_TEXT, _(Picture_Type_String(picture_types[i])),
-                               PICTURE_TYPE_COLUMN_TYPE_CODE, picture_types[i],
-                               -1);
-            // Line to select by default
-            if (pic->type == picture_types[i])
+            case MP4_TAG:
+            {
+                // Load picture type (only Front Cover!)
+                GtkTreeIter itertype;
+                
+                gtk_list_store_append(store, &itertype);
+                gtk_list_store_set(store, &itertype,
+                                   PICTURE_TYPE_COLUMN_TEXT, _(Picture_Type_String(PICTURE_TYPE_FRONT_COVER)),
+                                   PICTURE_TYPE_COLUMN_TYPE_CODE, PICTURE_TYPE_FRONT_COVER,
+                                   -1);
+                // Line to select by default
                 type_iter_to_select = itertype;
+                break;
+            }
+            
+            // Other tag types
+            default:
+            {
+                // Load pictures types
+                for (i = 0; i < sizeof(picture_types)/sizeof(picture_types[0]); i++)
+                {
+                    GtkTreeIter itertype;
+                    
+                    gtk_list_store_append(store, &itertype);
+                    gtk_list_store_set(store, &itertype,
+                                       PICTURE_TYPE_COLUMN_TEXT, _(Picture_Type_String(picture_types[i])),
+                                       PICTURE_TYPE_COLUMN_TYPE_CODE, picture_types[i],
+                                       -1);
+                    // Line to select by default
+                    if (pic->type == picture_types[i])
+                        type_iter_to_select = itertype;
+                }
+                break;
+            }
         }
+        
         // Select the line by default
         selectiontype = gtk_tree_view_get_selection(GTK_TREE_VIEW(type));
         gtk_tree_selection_select_iter(selectiontype, &type_iter_to_select);
 
+        // Set visible the current selected line
+        rowPath = gtk_tree_model_get_path(GTK_TREE_MODEL(store), &type_iter_to_select);
+        gtk_tree_view_scroll_to_cell(GTK_TREE_VIEW(type), rowPath, NULL, FALSE, 0, 0);
+        gtk_tree_path_free(rowPath);
+
         // Description
         label = gtk_label_new(_("Picture Description:"));
         gtk_box_pack_start(GTK_BOX(GTK_DIALOG(PictureTypesWindow)->vbox),label,FALSE,FALSE,4);
@@ -437,6 +522,23 @@ void Picture_Properties_Button_Clicked (GObject *object)
             g_free(tmp);
         }
     
+        // Behaviour following the tag type...
+        switch (ETCore->ETFileDisplayed->ETFileDescription->TagType)
+        {
+            case MP4_TAG:
+            {
+                gtk_widget_set_sensitive(GTK_WIDGET(label), FALSE);
+                gtk_widget_set_sensitive(GTK_WIDGET(desc), FALSE);
+                break;
+            }
+            
+            // Other tag types
+            default:
+            {
+                break;
+            }
+        }
+        
         gtk_widget_show_all(PictureTypesWindow);
         
         if (gtk_dialog_run(GTK_DIALOG(PictureTypesWindow)) == GTK_RESPONSE_OK)
@@ -497,6 +599,8 @@ void Picture_Save_Button_Clicked (GObject *object)
     gint selection_nbr, selection_i = 1;
 
 
+    if (!PictureEntryView) return;
+
     parent_window = (GtkWindow*) gtk_widget_get_toplevel(GTK_WIDGET(object));
     if (!GTK_WIDGET_TOPLEVEL(parent_window))
     {
@@ -508,6 +612,7 @@ void Picture_Save_Button_Clicked (GObject *object)
     selection      = gtk_tree_view_get_selection(GTK_TREE_VIEW(PictureEntryView));
     selection_list = gtk_tree_selection_get_selected_rows(selection, NULL);
     selection_nbr  = gtk_tree_selection_count_selected_rows(GTK_TREE_SELECTION(selection));
+
     while (selection_list)
     {
         GtkTreePath *path = selection_list->data;
@@ -730,12 +835,31 @@ gchar *Picture_Info (Picture *pic)
     size_str = Convert_Size_1((gfloat)pic->size);
 
     s = g_string_new(0);
-    g_string_sprintf(s, "%s (%s - %dx%d %s)\n%s: %s\n%s: %s",
-                     format, 
-                     size_str,
-                     pic->width, pic->height, _("pixels"),
-                     _("Type"), type,
-                     _("Description"), desc);
+    // Behaviour following the tag type...
+    switch (ETCore->ETFileDisplayed->ETFileDescription->TagType)
+    {
+        case MP4_TAG:
+        {
+            g_string_sprintf(s, "%s (%s - %dx%d %s)\n%s: %s",
+                             format, 
+                             size_str,
+                             pic->width, pic->height, _("pixels"),
+                             _("Type"), type);
+            break;
+        }
+        
+        // Other tag types
+        default:
+        {
+            g_string_sprintf(s, "%s (%s - %dx%d %s)\n%s: %s\n%s: %s",
+                             format, 
+                             size_str,
+                             pic->width, pic->height, _("pixels"),
+                             _("Type"), type,
+                             _("Description"), desc);
+            break;
+        }
+    }
     r = ET_Utf8_Validate_Full_String(s->str);
     g_string_free(s, TRUE); // TRUE to free also 's->str'!
     g_free(size_str);
@@ -768,7 +892,9 @@ void PictureEntry_Clear (void)
 void PictureEntry_Update (Picture *pic, gint select)
 {
     GdkPixbufLoader *loader = 0;
-    
+
+    if (!pic || !PictureEntryView) return;
+
     if (!pic->data)
     {
         PictureEntry_Clear();
@@ -827,6 +953,20 @@ void PictureEntry_Update (Picture *pic, gint select)
                 if (select)
                     gtk_tree_selection_select_iter(selection, &iter1);
                 gdk_pixbuf_unref(scaled_pixbuf);
+            }else
+            {
+                GtkWidget *msgbox = NULL;
+                gchar *msg = NULL;
+                
+                msg = g_strdup(_("Can't display the picture, as not enough data "
+                    "has been read to determine how to create the image buffer."));
+                g_print("%s\n",msg);
+                msgbox = msg_box_new (_("Loading Picture File..."),msg,
+                    GTK_STOCK_DIALOG_ERROR,BUTTON_YES,0);
+                msg_box_hide_check_button(MSG_BOX(msgbox));
+                g_free(msg);
+                msg_box_run(MSG_BOX(msgbox));
+                gtk_widget_destroy(msgbox);
             }
         }
     }
@@ -888,7 +1028,6 @@ void Picture_Free (Picture *pic)
     g_free(pic);
 }
 
-#define LOAD_BUFFER_SIZE 4096
 
 /*
  * Load the picture represented by the 'filename' (must be passed in
@@ -899,10 +1038,16 @@ Picture *Picture_Load_File_Data (const gchar *filename)
     Picture *pic;
     gchar *buffer = 0;
     size_t size = 0;
-    gint fd;
+    struct stat st;
+
+    if (lstat(filename, &st)==-1)
+        return (Picture *)NULL;
+
+    size = st.st_size;
+    buffer = g_malloc(size);
     
-    fd = open(filename, O_RDONLY);
-    if (fd == -1)
+    FILE *fd = fopen(filename, "rb");
+    if (!fd)
     {
         gchar *msg;
         gchar *filename_utf8;
@@ -923,25 +1068,10 @@ Picture *Picture_Load_File_Data (const gchar *filename)
         return FALSE;
     }
     
-    do
-    {
-        ssize_t r;
-        gchar *p;
-        
-        p = g_realloc(buffer, size + LOAD_BUFFER_SIZE);
-        if (!p)
-            goto fail;
-        buffer = p;
-        
-        r = read(fd, buffer + size, LOAD_BUFFER_SIZE);
-        if (r == -1)
-            goto fail;
-        if (!r)
-            break;
-        
-        size += r;
-    } while (1);
-    close(fd);
+    if (fread(buffer, size, 1, fd) != 1)
+      goto fail;
+
+    fclose(fd);
     
     pic = Picture_Allocate();
     pic->size = size;
@@ -951,7 +1081,7 @@ Picture *Picture_Load_File_Data (const gchar *filename)
     fail:
         if (buffer)
             g_free(buffer);
-        close(fd);
+        fclose(fd);
         return (Picture *)NULL;
 }
 
