@@ -42,9 +42,9 @@
 #include "cddb.h"
 #include "charset.h"
 
-#ifdef WIN32
-#   include "win32dep.h"
-#endif
+//#ifdef WIN32
+//#   include "win32dep.h"
+//#endif
 
 
 /**************
@@ -115,6 +115,7 @@ void Open_OptionsWindow (void)
     gtk_window_set_position(GTK_WINDOW(OptionsWindow),GTK_WIN_POS_CENTER);
     gtk_window_set_transient_for(GTK_WINDOW(OptionsWindow),GTK_WINDOW(MainWindow));
     gtk_container_set_border_width(GTK_CONTAINER(OptionsWindow), 5);
+    gtk_window_set_default_size(GTK_WINDOW(OptionsWindow),OPTIONS_WINDOW_WIDTH,OPTIONS_WINDOW_HEIGHT);
     /* Title */
     gtk_window_set_title(GTK_WINDOW(OptionsWindow),_("Preferences..."));
 
@@ -330,7 +331,9 @@ void Open_OptionsWindow (void)
         "when loading a directory."),NULL);
 
     SortingFileCaseSensitive = gtk_check_button_new_with_label(_("Case sensitive"));
+#ifndef WIN32 /* Always true and not user modifiable on win32, as strncasecmp() don't work correctly with g_utf8_collate_key() */
     gtk_box_pack_start(GTK_BOX(hbox),SortingFileCaseSensitive,FALSE,FALSE,0);
+#endif
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(SortingFileCaseSensitive),
         SORTING_FILE_CASE_SENSITIVE);
     gtk_tooltips_set_tip(Tips,SortingFileCaseSensitive,_("If activated, the "
@@ -618,7 +621,9 @@ void Open_OptionsWindow (void)
      */
     Label = gtk_label_new (_("ID3 Tag Settings"));
     Frame = gtk_frame_new (_("ID3 Tag Settings"));
+#ifdef ENABLE_MP3
     gtk_notebook_append_page (GTK_NOTEBOOK(OptionsNoteBook),Frame,Label);
+#endif
     gtk_container_set_border_width(GTK_CONTAINER(Frame),5);
 
     VBox = gtk_vbox_new(FALSE,2);
@@ -842,7 +847,6 @@ void Open_OptionsWindow (void)
     Use_Non_Standard_Id3_Writing_Character_Set_Toggled();
 
 
-
     /*
      * Scanner
      */
@@ -1342,6 +1346,8 @@ void OptionsWindow_Quit(void)
         Save_Default_Tag_Comment_Text_List(DefaultCommentModel, MISC_COMBO_TEXT);
         Save_Audio_File_Player_List(FilePlayerModel, MISC_COMBO_TEXT);
 
+        OptionsWindow_Apply_Changes();
+
         /* Now quit */
         gtk_widget_destroy(OptionsWindow);
         OptionsWindow = (GtkWidget *)NULL;
@@ -1349,6 +1355,34 @@ void OptionsWindow_Quit(void)
     }
 }
 
+/*
+ * For the configuration file...
+ */
+void OptionsWindow_Apply_Changes (void)
+{
+    if (OptionsWindow)
+    {
+        //gint x, y;
+        gint width, height;
+
+        if ( OptionsWindow->window!=NULL && gdk_window_is_visible(OptionsWindow->window)
+        &&   gdk_window_get_state(OptionsWindow->window)!=GDK_WINDOW_STATE_MAXIMIZED )
+        {
+            // Position and Origin of the preferences window
+            //gdk_window_get_root_origin(OptionsWindow->window,&x,&y);
+            //OPTIONS_WINDOW_X = x;
+            //OPTIONS_WINDOW_Y = y;
+            gdk_window_get_size(OptionsWindow->window,&width,&height);
+            OPTIONS_WINDOW_WIDTH  = width;
+            OPTIONS_WINDOW_HEIGHT = height;
+        }
+
+        /* Get the last visible notebook page */
+        OPTIONS_NOTEBOOK_PAGE = gtk_notebook_get_current_page(GTK_NOTEBOOK(OptionsNoteBook));
+    }
+}
+
+
 
 /*
  * Check_Config: Check if config informations are correct
@@ -1378,11 +1412,6 @@ gint Check_DefaultPathToMp3 (void)
 
     path_real = filename_from_display(path_utf8);
 
-#ifdef WIN32
-    ET_win32_path_remove_trailing_slash(path_real);
-    ET_win32_path_replace_backslashes(path_real);
-#endif
-
     if ( stat(path_real,&stbuf)==0 && S_ISDIR(stbuf.st_mode) )
     {
         g_free(path_real);
