@@ -105,26 +105,26 @@ gchar *CDDB_SEARCH_STRING_IN_RESULT_HISTORY_FILE   = ".easytag/cddb_search_strin
  ********************/
 tConfigVariable Config_Variables[] =
 {
-    {"load_on_startup",                 CV_TYPE_BOOL,    &LOAD_ON_STARTUP                   },
-    {"default_path_to_mp3",             CV_TYPE_STRING,  &DEFAULT_PATH_TO_MP3               },
-    {"browser_line_style",              CV_TYPE_BOOL,    &BROWSER_LINE_STYLE                },
-    {"browser_expander_style",          CV_TYPE_BOOL,    &BROWSER_EXPANDER_STYLE            },
-    {"browse_subdir",                   CV_TYPE_BOOL,    &BROWSE_SUBDIR                     },
-    {"browse_hidden_dir",               CV_TYPE_BOOL,    &BROWSE_HIDDEN_DIR                 },
-    {"open_selected_browser_node",      CV_TYPE_BOOL,    &OPEN_SELECTED_BROWSER_NODE        },
+    {"load_on_startup",                     CV_TYPE_BOOL,    &LOAD_ON_STARTUP                   },
+    {"default_path_to_mp3",                 CV_TYPE_STRING,  &DEFAULT_PATH_TO_MP3               },
+    {"browser_line_style",                  CV_TYPE_BOOL,    &BROWSER_LINE_STYLE                },
+    {"browser_expander_style",              CV_TYPE_BOOL,    &BROWSER_EXPANDER_STYLE            },
+    {"browse_subdir",                       CV_TYPE_BOOL,    &BROWSE_SUBDIR                     },
+    {"browse_hidden_dir",                   CV_TYPE_BOOL,    &BROWSE_HIDDEN_DIR                 },
+    {"open_selected_browser_node",          CV_TYPE_BOOL,    &OPEN_SELECTED_BROWSER_NODE        },
 
-    {"set_main_window_position",        CV_TYPE_BOOL,    &SET_MAIN_WINDOW_POSITION          },
-    {"main_window_x",                   CV_TYPE_INT,     &MAIN_WINDOW_X                     },
-    {"main_window_y",                   CV_TYPE_INT,     &MAIN_WINDOW_Y                     },
-    {"main_window_height",              CV_TYPE_INT,     &MAIN_WINDOW_HEIGHT                },
-    {"main_window_width",               CV_TYPE_INT,     &MAIN_WINDOW_WIDTH                 },
-    {"pane_handle_position1",           CV_TYPE_INT,     &PANE_HANDLE_POSITION1             },
-    {"pane_handle_position2",           CV_TYPE_INT,     &PANE_HANDLE_POSITION2             },
-    {"pane_handle_position3",           CV_TYPE_INT,     &PANE_HANDLE_POSITION3             },
-    {"show_header_infos",               CV_TYPE_BOOL,    &SHOW_HEADER_INFO                  },
-    {"use_colored_tooltips",            CV_TYPE_BOOL,    &USE_COLORED_TOOLTIPS              },
-    {"changed_files_displayed_to_red",  CV_TYPE_BOOL,    &CHANGED_FILES_DISPLAYED_TO_RED    },
-    {"changed_files_displayed_to_bold", CV_TYPE_BOOL,    &CHANGED_FILES_DISPLAYED_TO_BOLD   },
+    {"set_main_window_position",            CV_TYPE_BOOL,    &SET_MAIN_WINDOW_POSITION          },
+    {"main_window_x",                       CV_TYPE_INT,     &MAIN_WINDOW_X                     },
+    {"main_window_y",                       CV_TYPE_INT,     &MAIN_WINDOW_Y                     },
+    {"main_window_height",                  CV_TYPE_INT,     &MAIN_WINDOW_HEIGHT                },
+    {"main_window_width",                   CV_TYPE_INT,     &MAIN_WINDOW_WIDTH                 },
+    {"pane_handle_position1",               CV_TYPE_INT,     &PANE_HANDLE_POSITION1             },
+    {"pane_handle_position2",               CV_TYPE_INT,     &PANE_HANDLE_POSITION2             },
+    {"pane_handle_position3",               CV_TYPE_INT,     &PANE_HANDLE_POSITION3             },
+    {"show_header_infos",                   CV_TYPE_BOOL,    &SHOW_HEADER_INFO                  },
+    {"use_colored_tooltips",                CV_TYPE_BOOL,    &USE_COLORED_TOOLTIPS              },
+    {"changed_files_displayed_to_red",      CV_TYPE_BOOL,    &CHANGED_FILES_DISPLAYED_TO_RED    },
+    {"changed_files_displayed_to_bold",     CV_TYPE_BOOL,    &CHANGED_FILES_DISPLAYED_TO_BOLD   },
 
     {"date_auto_completion",                 CV_TYPE_BOOL,    &DATE_AUTO_COMPLETION                     },
     {"number_track_formated",                CV_TYPE_BOOL,    &NUMBER_TRACK_FORMATED                    },
@@ -132,7 +132,7 @@ tConfigVariable Config_Variables[] =
     {"ogg_tag_write_xmms_comment",           CV_TYPE_BOOL,    &OGG_TAG_WRITE_XMMS_COMMENT               },
     {"set_focus_to_same_tag_field",          CV_TYPE_BOOL,    &SET_FOCUS_TO_SAME_TAG_FIELD              },
     {"set_focus_to_first_tag_field",         CV_TYPE_BOOL,    &SET_FOCUS_TO_FIRST_TAG_FIELD             },
-    {"sorting_file_mode",                    CV_TYPE_BOOL,    &SORTING_FILE_MODE                        },
+    {"sorting_file_mode",                    CV_TYPE_INT,     &SORTING_FILE_MODE                        },
     {"sorting_file_case_sensitive",          CV_TYPE_BOOL,    &SORTING_FILE_CASE_SENSITIVE              },
 
     {"replace_illegal_character_in_filename",CV_TYPE_BOOL,    &REPLACE_ILLEGAL_CHARACTERS_IN_FILENAME   },
@@ -144,22 +144,22 @@ tConfigVariable Config_Variables[] =
     {"filename_character_set_approximate",   CV_TYPE_BOOL,    &FILENAME_CHARACTER_SET_APPROXIMATE       },
     {"filename_character_set_discard",       CV_TYPE_BOOL,    &FILENAME_CHARACTER_SET_DISCARD           },
 
-    {"write_id3v1_tag",                                 CV_TYPE_BOOL,  &WRITE_ID3V1_TAG                             },
-    {"write_id3v2_tag",                                 CV_TYPE_BOOL,  &WRITE_ID3V2_TAG                             },
-    {"write_id3_tags_in_flac_file",                     CV_TYPE_BOOL,  &WRITE_ID3_TAGS_IN_FLAC_FILE                 },
-    {"use_id3v2_padding",                               CV_TYPE_BOOL,  &USE_ID3V2_PADDING                           },
-    {"strip_tag_when_empty_fields",                     CV_TYPE_BOOL,  &STRIP_TAG_WHEN_EMPTY_FIELDS                 },
-    {"convert_old_id3v2_tag_version",                   CV_TYPE_BOOL,  &CONVERT_OLD_ID3V2_TAG_VERSION               },
-    {"use_id3_iso_8859_1_character_set",                CV_TYPE_BOOL,  &USE_ID3_ISO_8859_1_CHARACTER_SET            },
-    {"use_id3_iso_8859_1_then_unicode_character_set",   CV_TYPE_BOOL,  &USE_ID3_ISO_8859_1_THEN_UNICODE_CHARACTER_SET    },
-    {"use_id3_unicode_character_set",                   CV_TYPE_BOOL,  &USE_ID3_UNICODE_CHARACTER_SET               },
-    {"use_non_standard_id3_reading_character_set",      CV_TYPE_BOOL,  &USE_NON_STANDARD_ID3_READING_CHARACTER_SET  },
-    {"use_non_standard_id3_writing_character_set",      CV_TYPE_BOOL,  &USE_NON_STANDARD_ID3_WRITING_CHARACTER_SET  },
-    {"id3_file_reading_character_set",                  CV_TYPE_STRING,&ID3_FILE_READING_CHARACTER_SET              },
-    {"id3_file_writing_character_set",                  CV_TYPE_STRING,&ID3_FILE_WRITING_CHARACTER_SET              },
-    {"file_writing_character_set_other",                CV_TYPE_BOOL,  &FILE_WRITING_CHARACTER_SET_OTHER            },
-    {"file_writing_character_set_approximate",          CV_TYPE_BOOL,  &FILE_WRITING_CHARACTER_SET_APPROXIMATE      },
-    {"file_writing_character_set_discard",              CV_TYPE_BOOL,  &FILE_WRITING_CHARACTER_SET_DISCARD          },
+    {"write_id3v1_tag",                                 CV_TYPE_BOOL,  &WRITE_ID3V1_TAG                                 },
+    {"write_id3v2_tag",                                 CV_TYPE_BOOL,  &WRITE_ID3V2_TAG                                 },
+    {"write_id3_tags_in_flac_file",                     CV_TYPE_BOOL,  &WRITE_ID3_TAGS_IN_FLAC_FILE                     },
+    {"use_id3v2_padding",                               CV_TYPE_BOOL,  &USE_ID3V2_PADDING                               },
+    {"strip_tag_when_empty_fields",                     CV_TYPE_BOOL,  &STRIP_TAG_WHEN_EMPTY_FIELDS                     },
+    {"convert_old_id3v2_tag_version",                   CV_TYPE_BOOL,  &CONVERT_OLD_ID3V2_TAG_VERSION                   },
+    {"use_id3_iso_8859_1_character_set",                CV_TYPE_BOOL,  &USE_ID3_ISO_8859_1_CHARACTER_SET                },
+    {"use_id3_iso_8859_1_then_unicode_character_set",   CV_TYPE_BOOL,  &USE_ID3_ISO_8859_1_THEN_UNICODE_CHARACTER_SET   },
+    {"use_id3_unicode_character_set",                   CV_TYPE_BOOL,  &USE_ID3_UNICODE_CHARACTER_SET                   },
+    {"use_non_standard_id3_reading_character_set",      CV_TYPE_BOOL,  &USE_NON_STANDARD_ID3_READING_CHARACTER_SET      },
+    {"use_non_standard_id3_writing_character_set",      CV_TYPE_BOOL,  &USE_NON_STANDARD_ID3_WRITING_CHARACTER_SET      },
+    {"id3_file_reading_character_set",                  CV_TYPE_STRING,&ID3_FILE_READING_CHARACTER_SET                  },
+    {"id3_file_writing_character_set",                  CV_TYPE_STRING,&ID3_FILE_WRITING_CHARACTER_SET                  },
+    {"file_writing_character_set_other",                CV_TYPE_BOOL,  &FILE_WRITING_CHARACTER_SET_OTHER                },
+    {"file_writing_character_set_approximate",          CV_TYPE_BOOL,  &FILE_WRITING_CHARACTER_SET_APPROXIMATE          },
+    {"file_writing_character_set_discard",              CV_TYPE_BOOL,  &FILE_WRITING_CHARACTER_SET_DISCARD              },
 
     {"message_box_position_none",               CV_TYPE_BOOL,  &MESSAGE_BOX_POSITION_NONE               },
     {"message_box_position_center",             CV_TYPE_BOOL,  &MESSAGE_BOX_POSITION_CENTER             },
@@ -168,7 +168,7 @@ tConfigVariable Config_Variables[] =
 
     {"audio_file_player",                       CV_TYPE_STRING,&AUDIO_FILE_PLAYER                       },
 
-    {"scanner_type",                             CV_TYPE_BOOL,&SCANNER_TYPE                             },
+    {"scanner_type",                             CV_TYPE_INT, &SCANNER_TYPE                             },
     {"fts_convert_underscore_and_p20_into_space",CV_TYPE_BOOL,&FTS_CONVERT_UNDERSCORE_AND_P20_INTO_SPACE},
     {"fts_convert_space_into_underscore",        CV_TYPE_BOOL,&FTS_CONVERT_SPACE_INTO_UNDERSCORE        },
     {"rfs_convert_underscore_and_p20_into_space",CV_TYPE_BOOL,&RFS_CONVERT_UNDERSCORE_AND_P20_INTO_SPACE},
@@ -189,7 +189,6 @@ tConfigVariable Config_Variables[] =
     {"confirm_rename_file",                  CV_TYPE_BOOL,    &CONFIRM_RENAME_FILE                  },
     {"confirm_write_playlist",               CV_TYPE_BOOL,    &CONFIRM_WRITE_PLAYLIST               },
     {"confirm_delete_file",                  CV_TYPE_BOOL,    &CONFIRM_DELETE_FILE                  },
-    {"options_notebook_page",                CV_TYPE_INT,     &OPTIONS_NOTEBOOK_PAGE                },
     {"process_filename_field",               CV_TYPE_BOOL,    &PROCESS_FILENAME_FIELD               },
     {"process_title_field",                  CV_TYPE_BOOL,    &PROCESS_TITLE_FIELD                  },
     {"process_artist_field",                 CV_TYPE_BOOL,    &PROCESS_ARTIST_FIELD                 },
@@ -286,11 +285,14 @@ tConfigVariable Config_Variables[] =
     {"search_in_tag",                        CV_TYPE_BOOL,    &SEARCH_IN_TAG                        },
     {"search_case_sensitive",                CV_TYPE_BOOL,    &SEARCH_CASE_SENSITIVE                },
 
-
     {"scan_tag_default_mask",                CV_TYPE_STRING,  &SCAN_TAG_DEFAULT_MASK                },
     {"rename_file_default_mask",             CV_TYPE_STRING,  &RENAME_FILE_DEFAULT_MASK             },
     {"rename_directory_default_mask",        CV_TYPE_STRING,  &RENAME_DIRECTORY_DEFAULT_MASK        },
-    {"rename_directory_with_mask",           CV_TYPE_BOOL,    &RENAME_DIRECTORY_WITH_MASK           }
+    {"rename_directory_with_mask",           CV_TYPE_BOOL,    &RENAME_DIRECTORY_WITH_MASK           },
+
+    {"options_notebook_page",                CV_TYPE_INT,     &OPTIONS_NOTEBOOK_PAGE                },
+    {"options_window_height",                CV_TYPE_INT,     &OPTIONS_WINDOW_HEIGHT                },
+    {"options_window_width",                 CV_TYPE_INT,     &OPTIONS_WINDOW_WIDTH                 }
 
 };
 
@@ -343,15 +345,19 @@ void Init_Config_Variables (void)
     SET_FOCUS_TO_SAME_TAG_FIELD             = 1;
     SET_FOCUS_TO_FIRST_TAG_FIELD            = 0;
     SORTING_FILE_MODE                       = SORTING_BY_ASCENDING_FILENAME;
+#ifdef WIN32
+    SORTING_FILE_CASE_SENSITIVE             = 1;
+#else
     SORTING_FILE_CASE_SENSITIVE             = 0;
-    
+#endif
+
     MESSAGE_BOX_POSITION_NONE               = 0;
     MESSAGE_BOX_POSITION_CENTER             = 0;
     MESSAGE_BOX_POSITION_MOUSE              = 0;
     MESSAGE_BOX_POSITION_CENTER_ON_PARENT   = 1;
 
 #ifdef WIN32
-    AUDIO_FILE_PLAYER                       = ET_win32_get_audio_file_player();
+    AUDIO_FILE_PLAYER                       = ET_Win32_Get_Audio_File_Player();
 #else
     AUDIO_FILE_PLAYER                       = g_strdup("xmms -p");
 #endif
@@ -398,7 +404,7 @@ void Init_Config_Variables (void)
     RFS_CONVERT_UNDERSCORE_AND_P20_INTO_SPACE = 1;
     RFS_CONVERT_SPACE_INTO_UNDERSCORE         = 0;
     PFS_DONT_UPPER_SOME_WORDS                 = 0;
-    OVERWRITE_TAG_FIELD                       = 0;
+    OVERWRITE_TAG_FIELD                       = 1;
     SET_DEFAULT_COMMENT                       = 0;
     DEFAULT_COMMENT                           = g_strdup("Tagged with EasyTAG");
     SET_CRC32_COMMENT                         = 0;
@@ -541,6 +547,9 @@ void Init_Config_Variables (void)
      * Other parameters
      */
     OPTIONS_NOTEBOOK_PAGE = 0;
+    OPTIONS_WINDOW_HEIGHT = 300;
+    OPTIONS_WINDOW_WIDTH  = 400;
+    
 }
 
 
@@ -560,6 +569,9 @@ void Apply_Changes_Of_Preferences_Window (void)
         LOAD_ON_STARTUP               = GTK_TOGGLE_BUTTON(LoadOnStartup)->active;
         if (DEFAULT_PATH_TO_MP3) g_free(DEFAULT_PATH_TO_MP3);
         DEFAULT_PATH_TO_MP3           = g_strdup(gtk_entry_get_text(GTK_ENTRY(GTK_BIN(DefaultPathToMp3)->child))); // Saved in UTF-8
+#ifdef WIN32
+        ET_Win32_Path_Replace_Backslashes(DEFAULT_PATH_TO_MP3);
+#endif
         BROWSE_SUBDIR                 = GTK_TOGGLE_BUTTON(BrowseSubdir)->active;
         BROWSE_HIDDEN_DIR             = GTK_TOGGLE_BUTTON(BrowseHiddendir)->active;
         OPEN_SELECTED_BROWSER_NODE    = GTK_TOGGLE_BUTTON(OpenSelectedBrowserNode)->active;
@@ -631,7 +643,7 @@ void Apply_Changes_Of_Preferences_Window (void)
         ID3_FILE_WRITING_CHARACTER_SET = Charset_Get_Name_From_Title(temp);
         g_free(temp);
 
-        
+
         /* Scanner */
         // Fill Tag Scanner
         FTS_CONVERT_UNDERSCORE_AND_P20_INTO_SPACE = GTK_TOGGLE_BUTTON(FTSConvertUnderscoreAndP20IntoSpace)->active;
@@ -676,9 +688,6 @@ void Apply_Changes_Of_Preferences_Window (void)
         CONFIRM_DELETE_FILE    = GTK_TOGGLE_BUTTON(ConfirmDeleteFile)->active;
         CONFIRM_WRITE_PLAYLIST = GTK_TOGGLE_BUTTON(ConfirmWritePlayList)->active;
 
-        /* Get the last visible notebook page */
-        OPTIONS_NOTEBOOK_PAGE = gtk_notebook_get_current_page(GTK_NOTEBOOK(OptionsNoteBook));
-
         /* Parameters and variables of Scanner Window are in "scan.c" file */
         /* Parameters and variables of Cddb Window are in "cddb.c" file */
     }
@@ -729,6 +738,9 @@ void Apply_Changes_Of_UI (void)
     // Configuration of the main window (see easytag.c) - Function also called when destroying the window
     MainWindow_Apply_Changes();
 
+    // Configuration of the preference window (see prefs.c) - Function also called when destroying the window
+    OptionsWindow_Apply_Changes();
+
     // Configuration of the scanner window (see scan.c) - Function also called when destroying the window
     ScannerWindow_Apply_Changes();
     
